==> plone.i18n-4.0.7.tar.gz: plone.i18n-4.0.7/plone/i18n/locales/tests/test_countries.py <==
# -*- coding: UTF-8 -*-

import unittest


class TestAvailableCountries(unittest.TestCase):
    def setUp(self):
        from .base import setUp

        setUp()

    def tearDown(self):
        from .base import tearDown

        tearDown()

    def _makeOne(self):
        from zope.component import queryUtility
        from plone.i18n.locales.interfaces import ICountryAvailability

        return queryUtility(ICountryAvailability)

    def test_interface(self):
        from zope.interface.verify import verifyClass
        from plone.i18n.locales.interfaces import ICountryAvailability
        from plone.i18n.locales.countries import CountryAvailability

        self.assertTrue(verifyClass(ICountryAvailability, CountryAvailability))

    def test_get_available(self):
        util = self._makeOne()
        countrycodes = util.getAvailableCountries()
        self.assertTrue(len(countrycodes) > 200)
        self.assertIn(u"de", countrycodes)

    def test_get_countries(self):
        util = self._makeOne()
        countries = util.getCountries()
        self.assertTrue(len(countries) > 200)
        self.assert_(u"de" in countries)
        de = countries[u"de"]
        self.assertEqual(de[u"name"], u"Germany")
        self.assertEqual(de[u"flag"], u"/++resource++country-flags/de.gif")

    def test_get_country_listing(self):
        util = self._makeOne()
        countries = util.getCountryListing()
        self.assertTrue(len(countries) > 200)
        self.assertIn((u"de", u"Germany"), countries)

    def test_reservations(self):
        # our list has historically contained some reservations, which
        # aren't part of the official list. We retain those, to avoid
        # breaking content based on these
        from plone.i18n.locales.countries import _countrylist

        self.assertIn(u"an", _countrylist)
        self.assertIn(u"cs", _countrylist)

==> plone.i18n-5.0.0a3.tar.gz: plone.i18n-5.0.0a3/plone/i18n/locales/tests/test_countries.py <==
import unittest


class TestAvailableCountries(unittest.TestCase):
    def setUp(self):
        from .base import setUp

        setUp()

    def tearDown(self):
        from .base import tearDown

        tearDown()

    def _makeOne(self):
        from plone.i18n.locales.interfaces import ICountryAvailability
        from zope.component import queryUtility

        return queryUtility(ICountryAvailability)

    def test_interface(self):
        from plone.i18n.locales.countries import CountryAvailability
        from plone.i18n.locales.interfaces import ICountryAvailability
        from zope.interface.verify import verifyClass

        self.assertTrue(verifyClass(ICountryAvailability, CountryAvailability))

    def test_get_available(self):
        util = self._makeOne()
        countrycodes = util.getAvailableCountries()
        self.assertTrue(len(countrycodes) > 200)
        self.assertIn("de", countrycodes)

    def test_get_countries(self):
        util = self._makeOne()
        countries = util.getCountries()
        self.assertTrue(len(countries) > 200)
        self.assertIn("de", countries)
        de = countries["de"]
        self.assertEqual(de["name"], "Germany")
        self.assertEqual(de["flag"], "/++resource++country-flags/de.gif")

    def test_get_country_listing(self):
        util = self._makeOne()
        countries = util.getCountryListing()
        self.assertTrue(len(countries) > 200)
        self.assertIn(("de", "Germany"), countries)

    def test_reservations(self):
        # our list has historically contained some reservations, which
        # aren't part of the official list. We retain those, to avoid
        # breaking content based on these
        from plone.i18n.locales.countries import _countrylist

        self.assertIn("an", _countrylist)
        self.assertIn("cs", _countrylist)
